@@ -253,32 +253,32 @@
 #include "deque"
 // ./core/clingutils/G__listDict.cxx
 #include "list"
-// ./core/clingutils/G__vectorDict.cxx
-#include "vector"
 // ./core/clingutils/G__forward_listDict.cxx
 #include "forward_list"
-// ./core/clingutils/G__setDict.cxx
-#include "set"
+// ./core/clingutils/G__vectorDict.cxx
+#include "vector"
 // ./core/clingutils/G__multisetDict.cxx
 #include "set"
-// ./core/clingutils/G__multimapDict.cxx
-#include "map"
+// ./core/clingutils/G__setDict.cxx
+#include "set"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
 // ./core/clingutils/G__mapDict.cxx
 #include "map"
-// ./core/clingutils/G__unordered_multisetDict.cxx
-#include "unordered_set"
+// ./core/clingutils/G__multimapDict.cxx
+#include "map"
 // ./core/clingutils/G__unordered_setDict.cxx
 #include "unordered_set"
+// ./core/clingutils/G__unordered_multisetDict.cxx
+#include "unordered_set"
 // ./core/clingutils/G__map2Dict.cxx
 #include "map"
+// ./core/clingutils/G__valarrayDict.cxx
+#include "valarray"
 // ./core/clingutils/G__complexDict.cxx
 #include "root_std_complex.h"
 // ./core/clingutils/G__unordered_multimapDict.cxx
 #include "unordered_map"
-// ./core/clingutils/G__valarrayDict.cxx
-#include "valarray"
 // ./core/clingutils/G__unordered_mapDict.cxx
 #include "unordered_map"
 // ./core/imt/G__Imt.cxx
@@ -522,7 +522,6 @@
 #include "Minuit2/FumiliStandardChi2FCN.h"
 #include "Minuit2/FumiliStandardMaximumLikelihoodFCN.h"
 #include "Minuit2/FunctionGradient.h"
-#include "Minuit2/FunctionMinimizer.h"
 #include "Minuit2/FunctionMinimum.h"
 #include "Minuit2/GenericFunction.h"
 #include "Minuit2/GradientCalculator.h"
@@ -1015,6 +1014,7 @@
 #include "ROOT/RDF/RNewSampleNotifier.hxx"
 #include "ROOT/RDF/RSampleInfo.hxx"
 #include "ROOT/RDF/RDefineBase.hxx"
+#include "ROOT/RDF/RDefaultValueFor.hxx"
 #include "ROOT/RDF/RDefine.hxx"
 #include "ROOT/RDF/RDefinePerSample.hxx"
 #include "ROOT/RDF/RDefineReader.hxx"
@@ -1040,6 +1040,7 @@
 #include "ROOT/RDF/RRange.hxx"
 #include "ROOT/RDF/RResultMap.hxx"
 #include "ROOT/RDF/RSample.hxx"
+#include "ROOT/RDF/RFilterWithMissingValues.hxx"
 #include "ROOT/RDF/RTreeColumnReader.hxx"
 #include "ROOT/RDF/RVariation.hxx"
 #include "ROOT/RDF/RVariationBase.hxx"
@@ -1055,21 +1056,23 @@
 #include "ROOT/RCluster.hxx"
 #include "ROOT/RClusterPool.hxx"
 #include "ROOT/RColumn.hxx"
-#include "ROOT/RColumnElement.hxx"
-#include "ROOT/RColumnModel.hxx"
+#include "ROOT/RColumnElementBase.hxx"
 #include "ROOT/REntry.hxx"
 #include "ROOT/RField.hxx"
+#include "ROOT/RFieldBase.hxx"
 #include "ROOT/RFieldVisitor.hxx"
 #include "ROOT/RMiniFile.hxx"
 #include "ROOT/RNTuple.hxx"
-#include "ROOT/RNTupleCollectionWriter.hxx"
 #include "ROOT/RNTupleDescriptor.hxx"
 #include "ROOT/RNTupleFillContext.hxx"
+#include "ROOT/RNTupleFillStatus.hxx"
 #include "ROOT/RNTupleImtTaskScheduler.hxx"
+#include "ROOT/RNTupleIndex.hxx"
 #include "ROOT/RNTupleMerger.hxx"
 #include "ROOT/RNTupleMetrics.hxx"
 #include "ROOT/RNTupleModel.hxx"
 #include "ROOT/RNTupleParallelWriter.hxx"
+#include "ROOT/RNTupleProcessor.hxx"
 #include "ROOT/RNTupleReadOptions.hxx"
 #include "ROOT/RNTupleReader.hxx"
 #include "ROOT/RNTupleSerialize.hxx"
@@ -1284,6 +1287,7 @@
 #include "TASImage.h"
 #include "TASImagePlugin.h"
 #include "TASPluginGS.h"
+#include "TASPngWriter.h"
 // ./graf2d/asimage/G__ASImageGui.cxx
 #include "TASPaletteEditor.h"
 // ./graf2d/gviz/G__Gviz.cxx
@@ -1408,6 +1412,7 @@
 #include "TH2GL.h"
 #include "TH3GL.h"
 #include "TPointSet3DGL.h"
+#include "TGLSdfFontMaker.h"
 #include "TX11GL.h"
 // ./gui/gui/G__Gui.cxx
 #include "HelpText.h"
@@ -1688,9 +1693,9 @@
 #include "TMVA/RInferenceUtils.hxx"
 #include "TMVA/RBDT.hxx"
 #include "TMVA/RSofieReader.hxx"
-#include "TMVA/RBatchGenerator.hxx"
-#include "TMVA/RBatchLoader.hxx"
-#include "TMVA/RChunkLoader.hxx"
+#include "TMVA/BatchGenerator/RBatchGenerator.hxx"
+#include "TMVA/BatchGenerator/RBatchLoader.hxx"
+#include "TMVA/BatchGenerator/RChunkLoader.hxx"
 // ./tmva/tmvagui/G__TMVAGui.cxx
 #include "TMVA/BDT.h"
 #include "TMVA/BDTControlPlots.h"
@@ -1760,6 +1765,7 @@
 #include "TMVA/ROperator_Pool.hxx"
 #include "TMVA/ROperator_Concat.hxx"
 #include "TMVA/ROperator_Identity.hxx"
+#include "TMVA/ROperator_Constant.hxx"
 #include "TMVA/ROperator_Softmax.hxx"
 #include "TMVA/ROperator_Reduce.hxx"
 #include "TMVA/ROperator_Shape.hxx"
@@ -1773,6 +1779,9 @@
 #include "TMVA/ROperator_Comparision.hxx"
 #include "TMVA/ROperator_EyeLike.hxx"
 #include "TMVA/ROperator_Range.hxx"
+#include "TMVA/ROperator_TopK.hxx"
+#include "TMVA/ROperator_Tile.hxx"
+#include "TMVA/ROperator_Split.hxx"
 #include "TMVA/SOFIE_common.hxx"
 #include "TMVA/SOFIEHelpers.hxx"
 #include "TMVA/FunctionList.hxx"
@@ -1796,6 +1805,7 @@
 #include "RooAbsCategoryLValue.h"
 #include "RooAbsCollection.h"
 #include "RooAbsData.h"
+#include "RooAbsDataHelper.h"
 #include "RooAbsDataStore.h"
 #include "RooAbsFunc.h"
 #include "RooAbsGenContext.h"
@@ -1864,7 +1874,6 @@
 #include "RooFirstMoment.h"
 #include "RooFit.h"
 #include "RooFit/Config.h"
-#include "RooFit/Detail/BatchModeDataHelpers.h"
 #include "RooFit/Detail/CodeSquashContext.h"
 #include "RooFit/Detail/MathFuncs.h"
 #include "RooFit/Detail/NormalizationHelpers.h"
@@ -1982,12 +1991,6 @@
 #include "RooWorkspace.h"
 #include "RooWorkspaceHandle.h"
 #include "RooWrapperPdf.h"
-#include "RooAbsOptTestStatistic.h"
-#include "RooAbsTestStatistic.h"
-#include "RooChi2Var.h"
-#include "RooNLLVar.h"
-#include "RooRealMPFE.h"
-#include "RooXYChi2Var.h"
 // ./roofit/roofit/G__RooFit.cxx
 #include "Roo2DKeysPdf.h"
 #include "RooArgusBG.h"
@@ -2039,6 +2042,7 @@
 #include "RooParamHistFunc.h"
 #include "RooPoisson.h"
 #include "RooPolynomial.h"
+#include "RooPyBind.h"
 #include "RooSpline.h"
 #include "RooStepFunction.h"
 #include "RooTFnBinding.h"
@@ -2141,8 +2145,6 @@
 #include "RooStats/HistFactory/Sample.h"
 #include "RooStats/HistFactory/Systematics.h"
 #include "RooStats/HistFactory/ConfigParser.h"
-// ./roofit/RDataFrameHelpers/G__RooFitRDataFrameHelpers.cxx
-#include "RooAbsDataHelper.h"
 // ./roofit/jsoninterface/G__RooFitJSONInterface.cxx
 #include "RooFit/Detail/JSONInterface.h"
 // ./roofit/hs3/G__RooFitHS3.cxx
